"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _buffer = require("buffer");
var _tseep = require("tseep");
var _EventEmitters = require("./EventEmitters.js");
var _NativeTscUsb = _interopRequireDefault(require("./NativeTscUsb.js"));
var _types = require("./types.js");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
class UsbConnection extends _tseep.EventEmitter {
  static async discover(timeout) {
    if (!_NativeTscUsb.default) throw new Error('The TSC USB is not enabled.');
    const devices = await _NativeTscUsb.default.scanDevices(timeout);
    return devices.map(device => ({
      ...device,
      type: _types.ConnectionType.USB
    }));
  }
  constructor(id) {
    super();
    this._id = id;
    if (!_EventEmitters.usbEventEmitter) throw new Error('The TSC USB is not enabled.');
    this._usbDeviceAttachedListener = _EventEmitters.usbEventEmitter.addListener('connected', event => {
      if (event.id === this._id) {
        this.emit('connected');
      }
    });
    this._usbDeviceDetachedListener = _EventEmitters.usbEventEmitter.addListener('disconnected', event => {
      if (event.id === this._id) {
        this.emit('disconnected');
      }
    });
    this._usbDeviceDataListener = _EventEmitters.usbEventEmitter.addListener('data', event => {
      if (event.id === this._id) {
        this.emit('data', event.data);
      }
    });
  }
  static async connect(target) {
    if (!_NativeTscUsb.default) throw new Error('The TSC USB is not enabled.');
    return new UsbConnection(await _NativeTscUsb.default.connect(target));
  }
  async disconnect() {
    await _NativeTscUsb.default.disconnect(this._id);
    this._usbDeviceAttachedListener.remove();
    this._usbDeviceDetachedListener.remove();
    this._usbDeviceDataListener.remove();
  }
  async send(data) {
    await _NativeTscUsb.default.send(this._id, data.toString('base64'));
  }
  async read() {
    return _buffer.Buffer.from(await _NativeTscUsb.default.read(this._id), 'base64');
  }
}
var _default = exports.default = UsbConnection;
//# sourceMappingURL=UsbConnection.js.map