import { ConnectionType, SensorType, Font, TextAlignment, CodePage, BarcodeType, QRCodeMode, QRCodeModel, QRCodeMask } from './types';
import type { Device } from './types';
import { Buffer } from 'buffer';
export * from './types';
declare class Printer {
    private _type;
    private _connection;
    private constructor();
    static discover(types: ConnectionType[], timeout?: number): Promise<Device[]>;
    static connect(type: ConnectionType, target: string): Promise<Printer>;
    disconnect(): Promise<void>;
    receive(timeout?: number): Promise<string | Buffer>;
    sendCommand(command: string | Buffer): Promise<void>;
    clearBuffer(): Promise<void>;
    setSize(width: number, height: number): Promise<void>;
    setSpeed(speed: number): Promise<void>;
    setDensity(density: number): Promise<void>;
    setSensor(sensor: SensorType, distance: number, offset: number): Promise<void>;
    setCodepage(codepage: CodePage): Promise<void>;
    addBarcode(x: number, y: number, type: BarcodeType, content: string, size: number, { hri, rotation, narrow, wide, }?: {
        hri?: boolean;
        rotation?: number;
        narrow?: number;
        wide?: number;
    }): Promise<void>;
    addText(x: number, y: number, content: string | Buffer, { font, rotation, magnification, alignment, }?: {
        font?: Font | string;
        rotation?: number;
        magnification?: {
            x?: number;
            y?: number;
        };
        alignment?: TextAlignment;
    }): Promise<void>;
    addQRCode(x: number, y: number, content: string, cell?: number, { level, mode, rotation, model, mask, }?: {
        level?: 'L' | 'M' | 'Q' | 'H';
        mode?: QRCodeMode;
        rotation?: number;
        model?: QRCodeModel;
        mask?: QRCodeMask;
    }): Promise<void>;
    addBar(x: number, y: number, width: number, height: number): Promise<void>;
    print(quantity?: number, copies?: number): Promise<void>;
    feed(dots?: number): Promise<void>;
    formfeed(): Promise<void>;
    backfeed(dots?: number): Promise<void>;
    cut(): Promise<void>;
    noBackfeed(): Promise<void>;
    addImage(x: number, y: number, uri: string, heightInDots?: number): Promise<void>;
    addBitmap(x: number, y: number, widthBytes: number, heightInDots: number, bitmap: Uint8Array): Promise<void>;
    restart(): Promise<void>;
    getStatus(): Promise<string>;
    getPrinterName(): Promise<string>;
    getPrinterMemory(): Promise<string>;
    getPrinterMileage(): Promise<string>;
    getPrinterCodepage(): Promise<string>;
}
export default Printer;
//# sourceMappingURL=index.d.ts.map